import { Storage as r } from "./Storage.js";
class o extends r {
  /**
   * Get a value from the local storage.
   * @param key - The storage key.
   * @param defaultValue - The default value to return if the key is not found.
   * @returns the value from the local storage.
   * @throws if the local storage is not supported.
   * @example
   * ```typescript
   * const storage = new LocalStorage('oauth')
   * storage.set('test', 'value')
   * expect(storage.get('test')).toBe('value')
   * ```
   */
  get(e, t) {
    return this._checkSupport(), localStorage.getItem(this.key(e)) ?? t;
  }
  /**
   * Set a value in the local storage.
   * @param key - The storage key.
   * @param value - The value to store.
   * @throws if the local storage is not supported.
   * @example
   * ```typescript
   * const storage = new LocalStorage('oauth')
   * storage.set('test', 'value')
   * expect(storage.get('test')).toBe('value')
   * ```
   */
  set(e, t) {
    if (this._checkSupport(), t == null) {
      this.delete(e);
      return;
    }
    localStorage.setItem(this.key(e), t);
  }
  /**
   * Delete a value from the local storage.
   * @param name - The storage key.
   * @throws if the local storage is not supported.
   * @example
   * ```typescript
   * const storage = new LocalStorage('oauth')
   * storage.set('test', 'value')
   * expect(storage.get('test')).toBe('value')
   * storage.delete('test')
   * expect(storage.get('test')).toBeNull()
   * ```
   */
  delete(e) {
    this._checkSupport(), localStorage.removeItem(this.key(e));
  }
  /**
   * Clear all values from the local storage.
   * @throws if the local storage is not supported.
   * @example
   * ```typescript
   * const storage = new LocalStorage('oauth')
   * storage.set('test', 'value')
   * expect(storage.get('test')).toBe('value')
   * storage.clear()
   * expect(storage.get('test')).toBeNull()
   * ```
   */
  clear() {
    this._checkSupport();
    const e = this.key();
    for (const t in localStorage)
      t.indexOf(e) === 0 && this.delete(t);
  }
  /**
   * Check if the local storage is supported.
   * @returns true if the local storage is supported.
   * @example
   * ```typescript
   * expect(LocalStorage.supported()).toBe(true)
   * ```
   */
  static supported() {
    return typeof window < "u" && typeof localStorage < "u";
  }
  _checkSupport() {
    if (!o.supported())
      throw new Error("Local storage is not supported");
  }
}
export {
  o as LocalStorage
};
