export declare abstract class Storage {
    protected baseKey: string;
    /**
     * Creates a new storage instance.
     * @param baseKey - The base key for storage.
     */
    constructor(baseKey?: string);
    /**
     * Determines if the current browser supports this storage type.
     * @returns true if the storage type is supported.
     */
    static supported(): boolean;
    /**
     * Returns true if the storage has a value for the given key.
     * @param name - The storage key.
     * @returns true if the storage has a value for the given key.
     */
    has(name: string): boolean;
    /**
     * Returns a scoped key for storage.
     * @param key - The storage key.
     * @returns the scoped key for storage.
     */
    protected key(key?: string): string;
}
export interface Storage {
    get(name: string, defaultValue?: string): string | null | undefined;
    set(name: string, value: unknown): void;
    delete(name: string): void;
    clear(): void;
}
